from blocks.db.sql.sources import SQLReader
from blocks.db.sql.processors import SQLWriter


class SQLiteWriter(SQLWriter):
    ...


class SQLiteReader(SQLReader):
    ...
